@@ -1,7 +1,7 @@
 test_that(".libPaths helpers", {
   baseline <- .libPaths()
   r_version <- getRversion()
-  temp_dir <- tempdir()
+  temp_dir <- fs::path_temp()
 
   suppressMessages({
     temp_with_version <- add_lib_path(temp_dir, after = 1, version = TRUE)
@@ -9,11 +9,10 @@ test_that(".libPaths helpers", {
   })
 
   expect_true(endsWith(temp_with_version, as.character(r_version)))
-  expect_equal(temp_without_version, normalizePath(temp_dir, "/"))
+  expect_equal(temp_without_version, fs::path_real(temp_dir))
 
   remove_lib_path(temp_without_version, version = TRUE)
   remove_lib_path(temp_without_version, version = FALSE)
 
   expect_equal(baseline, .libPaths())
-
 })
