@@ -50,28 +50,6 @@ test_that("Unity Catalog API - don't perform", {
   )
   expect_s3_class(resp_schema_get, "httr2_request")
 
-  resp_table_summaries <- db_uc_table_summaries(
-    catalog = "some_catalog",
-    max_results = 10,
-    perform_request = F
-  )
-  expect_s3_class(resp_table_summaries, "httr2_request")
-
-  resp_tables_list <- db_uc_tables_list(
-    catalog = "some_catalog",
-    schema = "some_schema",
-    perform_request = F
-  )
-  expect_s3_class(resp_tables_list, "httr2_request")
-
-  resp_table_get <- db_uc_tables_get(
-    catalog = "some_catalog",
-    schema = "some_schema",
-    table = "some_table",
-    perform_request = F
-  )
-  expect_s3_class(resp_table_get, "httr2_request")
-
   resp_models_get <- db_uc_models_get(
     catalog = "some_catalog",
     schema = "some_schema",
@@ -102,15 +80,6 @@ test_that("Unity Catalog API - don't perform", {
   )
   expect_s3_class(resp_funcs_list, "httr2_request")
 
-  resp_volumes_list <- db_uc_volumes_list(
-    catalog = "some_catalog",
-    schema = "some_schema",
-    perform_request = F
-  )
-  expect_s3_class(resp_volumes_list, "httr2_request")
-
-
-
 })
 
 skip_on_cran()
@@ -175,32 +144,4 @@ test_that("Unity Catalog API", {
   })
   expect_type(resp_schema_get, "list")
 
-  expect_no_error({
-    resp_table_summaries <- db_uc_table_summaries(
-      catalog = "main",
-      max_results = 10
-    )
-  })
-  expect_type(resp_table_summaries, "list")
-
-  table_name <- strsplit(resp_table_summaries[[1]][[1]]$full_name, "\\.")[[1]]
-  expect_length(table_name, 3L)
-
-  expect_no_error({
-    resp_tables_list <- db_uc_tables_list(
-      catalog = "main",
-      schema = table_name[2]
-    )
-  })
-  expect_type(resp_tables_list, "list")
-
-  expect_no_error({
-    resp_table_get <- db_uc_tables_get(
-      catalog = "main",
-      schema = table_name[2],
-      table = table_name[3]
-    )
-  })
-  expect_type(resp_table_get, "list")
-
 })
